# BNC Scraper

This is a British National Corpus scraper

## TODO

- [x] downloader
- [ ] reader
  - [x] read by file
  - [x] read all files
  - [ ] search information
    - [ ] paragraph
    - [ ] conversational type
    - [ ] keywords
    - [x] title
    - [x] person infos
- [ ] group by
- [ ] printer
- [ ] export
